package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`MP`!````@!M```````!``````````("C````
M`````````$``.``)`$``'``;``8````$````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````;`````````!L``````````0`````````!````
M!0````````````````!``````````$```````,B3````````R),`````````
M``$```````$````&````P)T```````#`G4$``````,"=00``````4`0`````
M``"8%````````````0```````@````8```#8G0```````-B=00``````V)U!
M`````````@`````````"````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````B(P```````"(C$```````(B,0```````%`$````````4`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````,"=````````P)U!``````#`G4$`
M`````$`"````````0`(````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`8(P.4'&__6"_5=V4'+K',T51
M:FX$````$`````$```!'3E4```````,````'`````````!0````^`````@``
M``<```#0"!``40`("C@'2`$)"`@(/@```#\```!```````````````!!````
M`````$(``````````````$,`````````1````$4`````````1@```$<`````
M````2````$D```#9<5@<.?*+'*?=HVO)U;)Q"XH05U>DFY8A8F0'Q8D%D$-%
MU>S%N9Q`A_F<@7KP2FN[XY)\````````````````````````````````````
M`$T"```2`````````````````````````+4"```2````````````````````
M`````!T"```2`````````````````````````"0"```2````````````````
M`````````*<"```2`````````````````````````+T!```2````````````
M``````````````$````@`````````````````````````'4"```2````````
M`````````````````(T"```2`````````````````````````(8"```2````
M`````````````````````&T"```2`````````````````````````.<"```2
M`````````````````````````-@````2`````````````````````````!4!
M```2``````````````````````````\"```2````````````````````````
M`"L!```2`````````````````````````%0"```2````````````````````
M`````.<````2`````````````````````````+L````2````````````````
M`````````,(!```2`````````````````````````,L"```2````````````
M`````````````"L"```2`````````````````````````/4````2````````
M`````````````````)L!```2`````````````````````````!\!```2````
M`````````````````````*,!```2`````````````````````````/H!```2
M`````````````````````````!8"```2`````````````````````````-,!
M```2`````````````````````````-P!```2````````````````````````
M`+<!```2`````````````````````````%,````2````````````````````
M`````!T````@``````````````````````````("```2````````````````
M`````````+T"```2`````````````````````````#(!```2````````````
M`````````````#\"```2`````````````````````````,0"```2````````
M`````````````````,H!```2`````````````````````````#D"```2````
M`````````````````````(`````2```````````````````````````!```2
M`````````````````````````(P````2`````````````````````````&("
M```2`````````````````````````!H!```2````````````````````````
M`&4!```2`````````````````````````)T"```2````````````````````
M`````&,````2`````````````````````````+`````2````````````````
M`````````$$!```2`````````````````````````)8"```2````````````
M`````````````(\!```2``````````````````````````@"```2````````
M`````````````````)0!```2`````````````````````````,D````2````
M`````````````````````*<````2`````````````````````````#("```2
M`````````````````````````"P````@`````````````````````````'X!
M```2`````````````````````````.T!```2````````````````````````
M`/0!```2`````````````````````````%(#```0`!D`$*)!````````````
M`````'\"```1`!D`$*)!```````(`````````-\"```A`!D`**)!```````(
M`````````%(!```2````$!A``````````````````$8````1`!D`(*)!````
M```!`````````',!```1`!D`&*)!```````$`````````/D"```1`!0`T)U!
M```````(`````````-X"```A`!D`**)!```````(`````````$L#```0`!@`
M$*)!`````````````````-T"```1`!D`**)!```````(`````````&\````2
M````D!A``````````````````)<````2````\!5``````````````````%X#
M```0`!D`6+)!``````````````````!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!03%]D;U]U;F1U;7``4&5R;%]G=E]F971C:'!V`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7VQO8VL`4&5R;%]G971?<W8`4&5R;%]N97=84P!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]R=6X`<&5R;%]P87)S90!097)L7W-V7W-E='!V`%!E
M<FQ?<W9?<V5T<'9N`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?9&5S=')U8W0`<&5R
M;%]A;&QO8P!097)L7V-R;V%K7VYO8V]N=&5X=`!P97)L7V9R964`4&5R;%]S
M869E<WES;6%L;&]C`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%-?9FQA9W,`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`4$Q?=&AR7VME>0!?
M7V5R<FYO7VQO8V%T:6]N`')E860`;W!E;C8T`&QS965K-C0`<'1H<F5A9%]G
M971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC;7``9V5T<'=U:60`8VQO<V5D
M:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R
M=`!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S
M=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H
M:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`
M<F5A9&QI;FL`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK`&UE;6UO
M=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`
M7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS
M;RXU+C,R`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`$=,24)#7S(N,3<`
M```"``(``@`"``(``@````(``@`"``(``@```````@`"``(```````(``@`"
M`````P````,``@`"``(``@`#```````"``(````"``(``@`"``````````(`
M`@````(``````````@`#``(``P```````@````,``@`"``$``@`"````````
M``0``@`!``(```````$```````$``0`U`P``$````"````"7D98&```$`&,#
M`````````0`!`!L#```0````(````)>1E@8```,`8P,````````!``$`*P,`
M`!``````````EY&6!@```@!C`P```````."?00```````00``"$`````````
M`````-"=00````````0``$0``````````````!"B00````````0``#\`````
M`````````!BB00````````0``$,``````````````""B00````````0``$(`
M`````````````"BB00````````0``$<```````````````"@00```````@0`
M``$```````````````B@00```````@0```(``````````````!"@00``````
M`@0```,``````````````!B@00```````@0```0``````````````""@00``
M`````@0```4``````````````"B@00```````@0```8``````````````#"@
M00```````@0```@``````````````#B@00```````@0```D`````````````
M`$"@00```````@0```H``````````````$B@00```````@0```L`````````
M`````%"@00```````@0``$D``````````````%B@00```````@0```P`````
M`````````&"@00```````@0```T``````````````&B@00```````@0```X`
M`````````````'"@00```````@0```\``````````````'B@00```````@0`
M`!```````````````("@00```````@0``!$``````````````(B@00``````
M`@0``!(``````````````)"@00```````@0``!,``````````````)B@00``
M`````@0``!0``````````````*"@00```````@0``!4``````````````*B@
M00```````@0``!8``````````````+"@00```````@0``!<`````````````
M`+B@00```````@0``!@``````````````,"@00```````@0``!D`````````
M`````,B@00```````@0``!H``````````````-"@00```````@0``!L`````
M`````````-B@00```````@0``!P``````````````."@00```````@0``!T`
M`````````````.B@00```````@0``!X``````````````/"@00```````@0`
M`!\``````````````/B@00```````@0``"````````````````"A00``````
M`@0``"$```````````````BA00```````@0``"(``````````````!"A00``
M`````@0``",``````````````!BA00```````@0``"0``````````````""A
M00```````@0``"4``````````````"BA00```````@0``"8`````````````
M`#"A00```````@0``"<``````````````#BA00```````@0``"@`````````
M`````$"A00```````@0``"D``````````````$BA00```````@0``"H`````
M`````````%"A00```````@0``"L``````````````%BA00```````@0``"P`
M`````````````&"A00```````@0``$$``````````````&BA00```````@0`
M`"T``````````````'"A00```````@0``"X``````````````'BA00``````
M`@0``"\``````````````("A00```````@0``#```````````````(BA00``
M`````@0``#$``````````````)"A00```````@0``#(``````````````)BA
M00```````@0``#,``````````````*"A00```````@0``$@`````````````
M`*BA00```````@0``#0``````````````+"A00```````@0``#4`````````
M`````+BA00```````@0``#8``````````````,"A00```````@0``#<`````
M`````````,BA00```````@0``#@``````````````-"A00```````@0``#D`
M`````````````-BA00```````@0``#L``````````````."A00```````@0`
M`#P``````````````.BA00```````@0``#T``````````````%\D`]7]>[^I
M_0,`D:X!`)3]>\&HP`-?U@``````````\'N_J=```)`1_D?Y$.(_D2`"']8?
M(`/5'R`#U1\@`]70``"P$0)`^1`"`)$@`A_6T```L!$&0/D0(@"1(`(?UM``
M`+`1"D#Y$$(`D2`"'];0``"P$0Y`^1!B`)$@`A_6T```L!$20/D0@@"1(`(?
MUM```+`1%D#Y$*(`D2`"'];0``"P$1I`^1#"`)$@`A_6T```L!$>0/D0X@"1
M(`(?UM```+`1(D#Y$`(!D2`"'];0``"P$29`^1`B`9$@`A_6T```L!$J0/D0
M0@&1(`(?UM```+`1+D#Y$&(!D2`"'];0``"P$3)`^1""`9$@`A_6T```L!$V
M0/D0H@&1(`(?UM```+`1.D#Y$,(!D2`"'];0``"P$3Y`^1#B`9$@`A_6T```
ML!%"0/D0`@*1(`(?UM```+`11D#Y$"("D2`"'];0``"P$4I`^1!"`I$@`A_6
MT```L!%.0/D08@*1(`(?UM```+`14D#Y$(("D2`"'];0``"P$59`^1"B`I$@
M`A_6T```L!%:0/D0P@*1(`(?UM```+`17D#Y$.("D2`"'];0``"P$6)`^1`"
M`Y$@`A_6T```L!%F0/D0(@.1(`(?UM```+`1:D#Y$$(#D2`"'];0``"P$6Y`
M^1!B`Y$@`A_6T```L!%R0/D0@@.1(`(?UM```+`1=D#Y$*(#D2`"'];0``"P
M$7I`^1#"`Y$@`A_6T```L!%^0/D0X@.1(`(?UM```+`1@D#Y$`($D2`"'];0
M``"P$89`^1`B!)$@`A_6T```L!&*0/D00@21(`(?UM```+`1CD#Y$&($D2`"
M'];0``"P$9)`^1""!)$@`A_6T```L!&60/D0H@21(`(?UM```+`1FD#Y$,($
MD2`"'];0``"P$9Y`^1#B!)$@`A_6T```L!&B0/D0`@61(`(?UM```+`1ID#Y
M$"(%D2`"'];0``"P$:I`^1!"!9$@`A_6T```L!&N0/D08@61(`(?UM```+`1
MLD#Y$((%D2`"'];0``"P$;9`^1"B!9$@`A_6T```L!&Z0/D0P@61(`(?UM``
M`+`1OD#Y$.(%D2`"'];0``"P$<)`^1`"!I$@`A_6T```L!'&0/D0(@:1(`(?
MUM```+`1RD#Y$$(&D2`"'];0``"P$<Y`^1!B!I$@`A_6T```L!'20/D0@@:1
M(`(?UM```+`1UD#Y$*(&D2`"'];0``"P$=I`^1#"!I$@`A_6T```L!'>0/D0
MX@:1(`(?UM```+`1XD#Y$`('D2`"'];0``"P$>9`^1`B!Y$@`A_6T```L!'J
M0/D00@>1(`(?UM```+`1[D#Y$&('D2`"'];0``"P$?)`^1""!Y$@`A_6T```
ML!'V0/D0H@>1(`(?U@````````````````````#]>[NIPP``D&-`-Y']`P"1
M\U,!J>*'`JGBHP"1X<,`D>`_`+G@\P"19`!`^>0G`/D$`(#2@___EP(``)!"
M0""1X0,"J@```)``0"*1`0T`E,```+``@$@Y8`D`--,``+!SX@B1U```L(`:
M0KE-__^7X0,`JH`:0KDB:%(Y0@`?,B)H$CE'__^7X0,`JN(_0+E`$``15`P`
M$2)H4CD`?'V30@``,B)H$CDZ__^7XP,`JN8;0/G"``"PY3]`N2$``)!"!$'Y
M(>`%D<0`0/D@``"0```&D60$`*EC!@#Y8@`!J;\$`'%M"`!4(0"`TA\@`]4@
M#``1Q'AA^"$$`)%DV"#XOP`!:VS__U2E#``1I7Q]DV`.0/E_:"7XX@,4*@$`
M`+`$`(#2(=`/D7[__Y?T`P`J``0`-&`.0/GZ_O^7````\.$3`9$``#R1A@``
ME*`#`+1@#D#YX_[_EV;__Y?```"0X2=`^0+H1ODA``+K`@"`TH$$`%3@`Q0J
M\U-!J?U[Q:C``U_6TP``L'/B")'Y_O^78`X`^2`#`+34``"PS?[_EX`:0KG_
M_O^7'R0I.:___Q=@#D#Y>___E_0#`"K>__\78`I`^6```+1&!P"4X?__%^$3
M`9$```#P`$`ZD6$``)1@"@#Y8/O_M#X'`)39__\7!02`TL?__Q<@`(!2F?[_
ME_C^_Y<?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5
M'R`#U1\@`]4?(`/5'R`#U1\@`]5?)`/5'0"`TAX`@-+E`P"JX0-`^>(C`)'F
M`P"1``#@T@``P/(`"*#R`"B#\@,`X-(#`,#R`PB@\@.@B?($`.#2!`#`\@0(
MH/($L(GRL?[_E^3^_Y?```"0`/!'^4```+3<_O\7P`-?UA\@`]4?(`/5P```
ML`!`")'!``"P(4`(D3\``.O```!4`0``\"'<1OEA``"T\`,!J@`"'];``U_6
MP```L`!`")'!``"P(4`(D2$``,LB_'_300R!BR'\09/!``"T`@``\$+@1OEB
M``"T\`,"J@`"'];``U_6'R`#U?U[OJG]`P"1\PL`^=,``+!@PD@Y@```-=[_
M_Y<@`(!28,((.?,+0/G]>\*HP`-?UN3__Q<?(`/5'R`#U1\@`]7]>[RI_0,`
MD?-3`:E@!@"T]V,#J?<#`*K```"P&!1!^1@&`+3U6P*I]@,!JA4`@%+@`D`Y
M'_0`<0080'JA`@!4$P-`^;,!`+2U?D"3]`,8JN(#%:KA`Q>JX`,3JF'^_Y>`
M```U8&IU.!_T`'$``@!4DXY`^//^_[7U6T*I]V-#J>`#$ZKS4T&I_7O$J,`#
M7];U`Q>JH!Y`.!_T`'$$&$!ZH?__5+4"%TOF__\7E`(8R[4&`)%S`A6+E/Y#
MD]0"`+G@`Q.J\U-!J?5;0JGW8T.I_7O$J,`#7]83`(#2Z?__%Q,`@-+W8T.I
MYO__%Q\@`]7]>[.IP0``D"%`-Y']`P"1(@!`^>)G`/D"`(#2P```M/-3`:GS
M`P"J`0!`.4$!`#7S4T&IP```D.%G0/D"Z$;Y(0`"ZP(`@-(A"0!4_7O-J,`#
M7];__?^7]`,`JJ#^_[3W&P#Y%P``\/>".)'U6P*IX`,4JH_^_Y>`!0"T`4Q`
M.15,`)$_N`!Q@0``5*$&0#D!__\T'R`#U0!,0#D?N`!Q0`4`5.`#$ZK2_?^7
M]@,`JN`#%:K/_?^7P`(`"P`(`!$`?$"3^_W_E^4#%:KD`Q.JXP,7JO4#`*H"
M`("2(0"`4LC]_Y?B(P&1X0,5J@``@%+,_?^7'P0`,:```%3@6T"Y``P4$A\0
M0''``@!4X`,5JIS^_Y?@`Q6J7O[_E^`#%*ID_O^7P/K_M>`#%*H5_O^7X`,3
MJC_^_Y?S4T&I]5M"J?<;0/F\__\7H`9`.1^X`'&A^O]4H`I`.<#X_S32__\7
MX`,5JJ?__Y?K__\7\U,!J?5;`JGW&P#Y!O[_EQ\@`]7]>[6IP0``D/T#`)'S
M"P#Y\P,`JB!`-Y'A`Q.J`@!`^>)7`/D"`(#2``"`4N*C`)$P_O^7``(`->$[
M0+D"`)12(0P4$C\00'$D$$)Z@`$`5,$``)#B5T#Y(^A&^4(``^L#`(#2@0$`
M5/,+0/G]>\NHP`-?U@``@%+V__\7X`,3JD$`@%+W_?^7'P``<>`7GQKP__\7
MW_W_EQ\@`]4?(`/5_7N^J?T#`)'S"P#Y\P,`JG#]_Y<"!`#18@("BW\"`NNC
M``!4,```%$($`-%_`@+K``(`5$``0#D?O`!Q8/__5'\"`NL"!0!40@0`T7\"
M`NL``0!4'R`#U4``0#D?O`!QX`$`5$($`-%_`@+K8?__5&`"0#D?O`!QP`,`
M5/,+0/D```#0_7O"J`"@.)&Q_?\70`!`.1^\`'&!``!40@0`T7\"`NMC__]4
M0@`3RP``@-)!"`"1/P1`\0@!`%3```"0!&`)D4($`)'A`Q.JX`,$J@,`@M)S
M_?^7\PM`^?U[PJC``U_6?P("ZZ']_U3A__\7\PM`^0```-#]>\*H`$`WD93]
M_Q<,"(+2_V,LRZ,``/!C0#>1XO^!TOU[`*G]`P"1\U,!J?0#`:KAXP"1]5L"
MJ?4#`*I@`$#YX!\(^0``@-(```#0`,`XD3+]_Y<?``!QK04`5,$``)`#!`!1
M-AA"N>'C`)$AR&,X00,`-0,$`#1S?$"3X.,`D>(#$ZKA!8!2X/W_ET`#`+3@
M`Q8J:?W_E^,#$ZKBXP"1X0,5JN']_Y>@``#PX1](^0+H1ODA``+K`@"`TH$#
M`%0,"(+2_7M`J?-30:GU6T*I_V,LB\`#7];C`P`JX06`4N#C`)%S?$"3X@,3
MJL?]_Y<`_?^UX`,6*E#]_Y?B`Q2JX0,5JC']_Y?H__\7P```D!880KG@`Q8J
M2/W_E^(#%*KA`Q6J*?W_E^#__Q=3_?^7'R`#U1\@`]7]>[JI_0,`D?-3`:GT
M`P&JH0``\/5;`JDA0#>1\P,`JO=C`ZD@`$#YX"\`^0``@-*``D`Y'_0`<906
ME)K@`Q2JV/S_E_8#`*KA4P&1X`,3JIS^_Y<`"`"T]0,`JM'\_Y??`@#KR08`
M5/=7@+G8``"0]_)]TV`"0#D?]`!Q!!A`>H`+`%3C`Q.J8AQ`.%_T`'%$&$!Z
MH?__5&,`$\MC?$"3%1=!^<`*`)$```.+[?S_EZ!J-_C@`@"T`A=!^>`#$ZKC
M5X"Y`11`.$-X8_@_]`!Q)!A`>F$``#G@``!4'R`#U0(40#AB'``X7_0`<408
M0'J!__]4H0>`4@``@-)A%``X@FI@.&)H(#@`!`"1HO__-:```/#A+T#Y`NA&
M^2$``NL"`(#2`0<`5/-30:GU6T*I]V-#J?U[QJC``U_6`0"`TH)J83BB:B$X
M(00`D:+__S7P__\7V```D/EK!*D:%T'Y0`-`^:`$`+3@`QJJ%0"`4@&,0/CB
M`Q4JM08`$:'__[5`#``1`'Q]D\$``)`B.$*Y`@(`-2(`@%(B.`*YL?S_E_D#
M`*I``P"TMWY]D^$#&JKB`Q>J<_S_EQD7`?F@!@`1/]L@^/57`+GY:T2IJO__
M%^$#`*K@`QJJSOS_EP`7`?GY`P"J0`$`M+=^?9/T__\7`P"`TJO__Q<``H#2
M%0"`4N+__Q?Y:P2ISOS_E_EK1*G`__\7_7N^J?T#`)'S"P#YTP``D&`:0KFV
M_/^78!I"N;3\_Y<C``#0XO__\&/`+Y%"P!>1`0``T"$`.9'Q_/^78!I"N:O\
M_Y?S"T#Y!```\/U[PJB$P`61XP,$J@(``+`!``#00E`7D2&`.9$%`(!2!/W_
M%_U[OZG```"0_0,`D0`80KF;_/^7_7O!J",``-#B___P8\`OD4+`%Y$!``#0
M(0`YD=?\_Q<?(`/5'R`#U0P(A-+_8RS+H```\`!`-Y']>P"I_0,`D?-3`:D4
M`(#2`0!`^>$?$/D!`(#26?S_E^0#`"H%``#0`P``T*7@.9%C`#J1(@""TB$`
M@%+@HP"1*/S_EP(&@M+@HP"1X6,BBP(`@M(O_/^7H`'X-_,#`*H`!``1`'Q`
MDTK\_Y?T`P"JX```M'-^0),!!H+2X@,3JN%C(8L'_/^7GVHS.*```/#A'U#Y
M`NA&^2$``NL"`(#2X0``5.`#%*H,"(32_7M`J?-30:G_8RR+P`-?UFW\_Y?,
M__\7#!R"TO]C+,NB``#P0D`WD?U[`*G]`P"1\U,!J?,#`:KA4P&1]5L"J?4#
M`*I``$#YX&\(^0``@-(```#0`$`ZD;O]_Y?T`P"JX06`4N`#%:JO_/^70`(`
MM.$#%:H```#0`(`ZD0+__Y?@`Q6JH0``\.)O2/DCZ$;Y0@`#ZP,`@-*A#`!4
M#!R"TOU[0*GS4T&I]5M"J?]C+(O``U_6X`,5JA8``-#6PCJ1]V,#J=C[_Y?A
M`Q:J]P,`*N`#$ZK0^_^7\P,`JD`*`+08``#0&*,XD?DC`/D9``#0.4,WD6`"
M0#F`!@`TM```M.$#$ZK@`Q2J3_S_E^`$`#3@`Q.JQ/O_EP($`%'C`P"J8,(B
MBV'*8C@_O`!Q(0$`5!\@`]7C`P(J0@0`41\``#E@PB*+8<IB.#^\`'%`__]4
MX`8`$0,``PM__#]Q#`,`5.0#$ZKF`Q6JY0,8J@,``-!CX#J1`@""TB$`@%+@
M8P.1K?O_E^)C`9'A8P.1``"`4K'[_Y>@```UX&M`N0`,%!(?($!Q8`(`5.$#
M%JH``(#2F?O_E_,#`*K@^?^U]V-#J?DC0/FK__\7E```M(`"0#D?N`!Q@```
M5/,#&:HC`(!2W/__%X`&0#D`_O\T^___%^!C`Y$A`(!2!_S_EV#]_S7A8P.1
M````T`"`.I&>_O^7X&,#D>3[_Y?W8T.I^2-`^9G__Q?W8T.IDO__%_=C`ZGY
M(P#YY/O_EP(`0#GA`P"JP@``-"$$`)%?O`!Q`!"!FB(`0#F"__\UP`-?UA\@
M`]4?(`/5@```M`$`0#E!```T^?W_%P```-``0#>1ROO_%Q\@`]7]>[BI(```
MT`#`+Y']`P"1`D``D?-3`:FA``#P]5L"J2%`-Y$3``#0]V,#J7,".Y'4``"0
M!AQ!J2``0/G@/P#Y``"`TD!`0'E$%$&IYA\%J>07!JG@XP!YX3,!D>`#$ZH8
M_?^7X`$`M((60?GC3X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'_
M_[7A,P&1X`,3J@K]_Y=@_O^U$P``T'-".Y'4``"0X3,!D>`#$ZH#_?^7``(`
MM((60?GC3X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4!"$#Y`00`^0`@`)&A__^U
MX3,!D>`#$ZKT_/^70/[_M1,``-!S8CN1U```D.$S`9'@`Q.J[?S_EP`"`+2"
M%D'YXT^`N4`,`XL!!$#Y07@C^.'^_[0?(`/5`0A`^0$$`/D`(`"1H?__M>$S
M`9'@`Q.JWOS_ET#^_[43``#0<Z([D=0``)#A,P&1X`,3JM?\_Y<``@"T@A9!
M^>-/@+E`#`.+`01`^4%X(_CA_O^T'R`#U0$(0/D!!`#Y`"``D:'__[7A,P&1
MX`,3JLC\_Y=`_O^U$P``T'/".Y'4``"0X3,!D>`#$ZK!_/^7``(`M((60?GC
M3X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4!"$#Y`00`^0`@`)&A__^UX3,!D>`#
M$ZJR_/^70/[_M10``-"4`CR1U0``D.$S`9'@`Q2JJ_S_EP`"`+2B%D'YXT^`
MN4`,`XL!!$#Y07@C^.'^_[0?(`/5`0A`^0$$`/D`(`"1H?__M>$S`9'@`Q2J
MG/S_ET#^_[44``#0E$(ZD=4``)#A,P&1X`,4JI7\_Y<``@"THA9!^>-/@+E`
M#`.+`01`^4%X(_CA_O^T'R`#U0$(0/D!!`#Y`"``D:'__[7A,P&1X`,4JH;\
M_Y=`_O^U%0``T+5"/)'6``"0X3,!D>`#%:I__/^7``(`M,(60?GC3X"Y0`P#
MBP$$0/E!>"/XX?[_M!\@`]4!"$#Y`00`^0`@`)&A__^UX3,!D>`#%:IP_/^7
M0/[_M18``-#6@CR1UP``D.$S`9'@`Q:J:?S_EP`"`+3B%D'YXT^`N4`,`XL!
M!$#Y07@C^.'^_[0?(`/5`0A`^0$$`/D`(`"1H?__M>$S`9'@`Q:J6OS_ET#^
M_[47``#0]\(\D=@``)#A,P&1X`,7JE/\_Y<``@"T`A=!^>-/@+E`#`.+`01`
M^4%X(_CA_O^T'R`#U0$(0/D!!`#Y`"``D:'__[7A,P&1X`,7JD3\_Y=`_O^U
M%P``T/>".I'8``"0X3,!D>`#%ZH]_/^7``(`M`(70?GC3X"Y0`P#BP$$0/E!
M>"/XX?[_M!\@`]4!"$#Y`00`^0`@`)&A__^UX3,!D>`#%ZHN_/^70/[_M>$S
M`9$```#0```]D2G\_Y?A`P"J8```M.`#%JIU_?^7X3,!D0```-``8#V1(?S_
ME^$#`*J```"T````T`!@-Y%L_?^7X3,!D0```-``P#V1&/S_E^$#`*I``@"T
MX`,4JF3]_Y?@`Q.J`0``T"&@/I%@_?^7H```\.$_0/D"Z$;Y(0`"ZP(`@-+!
M`P!4\U-!J?5;0JGW8T.I_7O(J,`#7];A,P&1````T```/I$!_/^7X0,`JH``
M`+3@`Q6J3?W_E^G__Q<`*HC2X1-&^$#JJ_)@B,GRH"CH\C\``.M!_/]4X9-&
M>,"IAU(_``!KP?O_5.`#%:KAKP&1/OW_E]K__Q>,^O^7_7N]J:$``/`A0#>1
M_0,`D?,+`/G3``"08`)"N2(`0/GB%P#Y`@"`TA\$`#%``0!4H0``\.(70/DC
MZ$;Y0@`#ZP,`@-(A`@!4\PM`^?U[PZC``U_6X9,`D0```-``0#R1T_O_E^$#
M`*H``(!2H0``M"``0#D?P`!Q!!A`>N`'GQI@`@*YZ___%VGZ_Y?]>[^I_0,`
MD1+Z_Y>)^O^70```M```0/G]>\&HP`-?UOU[O*FA``#P(4`WD?T#`)'S4P&I
M%```T)3"/I'U6P*I]0,`JB``0/G@'P#Y``"`TN'3`)'@`Q2JLOO_ER`"`+0!
M`$`Y\P,`JL$!`#3A`Q6JP/K_E^`"`+2@``#PX1]`^0+H1ODA``+K`@"`TD$%
M`%3S4T&I]5M"J?U[Q*C``U_6H```\.$?0/D"Z$;Y(0`"ZP(`@-+A`Q6JX0,`
M5.`#%*KS4T&I]5M"J?U[Q*CE_/\7X`,5JLOY_Y?V`P"JX`,3JLCY_Y?``@"+
M``@`D?7Y_Y<A`(!2Y@,3J@(`@)+S`P"JY`,5J@4``-`#``#0I<`ZD6/@.I&_
M^?^7H```\.$?0/D"Z$;Y(0`"ZP(`@-+A`Q.J8/S_5!OZ_Y<?(`/5'R`#U0PT
MD-+_8RS+(@``T$+`+Y&A``#P(4`WD?U[`:G]0P"12*1#J?-3`JGU6P.I]@,`
MJN`C0)'W8P2I%P``T/=".I$D`$#Y!,P`^00`@-+H)P>IX`,7JDHL1:GALP&1
M1AQ&J>HO"JE$%$>IYA\+J4@D2*GHIPBI0R1`^>-#`/E"2$#YXD\`^>07#*E6
M^_^7@```M`$`0#GS`P"J@2``-?EK!:F<^?^7$_K_EP`<`+04`$#YU!L`M.`#
M%*J"^?^7`/A_TP`$`)&O^?^7A`)`.?4#`*J$`0`T&```T/,#%:H8(S^1X`,3
MJN,#&*H"`("2(0"`4GCY_Y=S"@"1A!Y`."3__S4!``#0](,"D2!@-Y$#```4
M@(Y`^(`)`+3ALP&1,?O_E_,#`*I@__^T`0!`.2'__S3(^_^7X/[_-.`#$ZK!
M^?^7\P,`J@`(`+3@`Q.J7?G_E_0#`*K@`Q6J6OG_EY0"``N4$A`1&0``L#FC
M.)&4?D"3X`,4JH/Y_Y?G`Q6JY`,3JN4#&:H&``"P`P``L,9`/Y%C8#^1`@"`
MDO4#`*HA`(!23/G_E^`#%:H!.(!2+?K_EQ\$`#&A``!4(OK_EP4`0+F_1`!Q
MX14`5.)#`Y'A`Q6J``"`4MOY_Y?S`P`JH`4`-*```/`"``#0PP)`^>0#%:H`
M"$'Y0J``D2$`@%(4`(#2M/G_E^$C0)&@``#0(LQ`^0/H1OE"``/K`P"`TF$G
M`%3@`Q2J##20TOU[0:GS4T*I]5M#J?=C1*GY:T6I_V,LB\`#7];XPP&1%`"`
M4A\@`]43VW3XLP$`M&`"0#E@`0`TE`8`$>`#$ZIZ^_^7(/__-.`#$ZIS^?^7
M\P,`JF#V_[43VW3XL_[_M1,`@-*O__\7X.-`N0`,%!(?$$!Q(?K_5/CK0+D;
M^?^7'P,`:Z'Y_U3@XT"Y`"``$A\`!W$A^?]4X`,4JB_Y_Y<!``#0]`,`JB``
M`I'ALP&1POK_EV`0`+38`D#Y5_G_E^$#`*K@`QBJ\?S_E_H#`*J`#P"TX`,:
MJO#X_Y?X`P"J'PP`<>T!`%0`?$"3`0``T``0`-$A(`*10`,`BV_Y_Y<``0`U
M'Q,`<0`9`%08%P!10,MX.!^\`'&`&`!4'R`#U;@``/`6``"PUD(\D0`#0KD?
M!``QH`P`5*`-`#3@`Q:J`0``L"&@/I'L^_^7%@``T-;"!9$8``#0&.,"D?OX
M_Y?F`P`JYP,6JN4#&:KD`Q6JX`,4J@,``-`"`("28Z`"D2$`@%+)^/^7$0``
M%*/Y_Y<``$"Y'T0`<4$"`%3K^/^7]@,`^7,&`!'F`P`JYP,3*N4#&:KD`Q6J
MXP,8JN`#%*H"`("2(0"`4KCX_Y?@`Q2J`3B`4IGY_Y<?!``Q@/W_5.`#%:I5
M^?^7X0,4JN`#%ZK"^_^7X`,4JK#^_Y=X__\7]2,"D1,`@%*@VG/X@`$`M.&S
M`9%S!@`1:/K_EV#__[0!`$`Y(?__-/SX_Y?T`P"JX.+_M:#:<_C`_O^UH`&`
MTL;X_Y<4``"P]0,`JI0"/Y%D"H!2%O__%Z```/#D`Q6JPP)`^0(``+``"$'Y
M0J`_D2$`@%(4`(#2#/G_EUC__Q>._O^7X2-`D:```-`BS$#Y`^A&^4(``^L#
M`(#201(`5.`#$ZH,-)#2_7M!J?-30JGU6T.I]V-$J?]C+(O7^/\7V@)`^83_
M_Q?ALP&1X`,6JCKZ_Y>@``"T``!`.1_``'$$&$!ZP0D`5!\#`KG@`QJJ`0"`
M4A8``+`X^?^7UD(\D?@#`"K`\?\T0@"`4B$"@)*R^/^7X6,&D>`#&"K"`(#2
M)OG_E^!C1CF````UX&=&.1\,`7%@"0!4`@"`4@$`@-+@`Q@JI?C_EW`%`)3S
M`P"J!0``%.(#`"KA8P:1X`,3JG\%`)3A8P:1X`,8*@(`D-(2^?^7'P``<>S^
M_U3@`Q@JLOC_E^$#$ZKSHP61&```L'JB`)$8(S^1X$,%D?8#`*JV!0"4'R`#
MU<060#C@`Q.JXP,8JG,*`)$"`("2(0"`4CKX_Y=?`Q/K`?__5.:C!9'E`QFJ
MY`,5J@<``-`#``#0Y\`%D6-@`I$"`("2(0"`4N`#%*K_0P8Y+/C_E^`#%:K.
M^/^7X0,4JN`#%ZH[^_^7X`,4JBG^_Y?Q_O\7(`"`4@`#`KE&__\7U@9`^;;G
M_[3@`Q:J&?C_EQ\,`/$IY_]4`!``T0$``-#``@"+(4`"D9KX_Y<?``!Q6A.6
MFC'__Q?@:T8Y'P0!<8'V_U3@;T8Y'PP!<2'V_U3@<T8Y'R`!<<'U_U3@=T8Y
M'Q0!<6'U_U3@`Q@J0@"`4B$'@))/^/^7X6,&D>`#&"HB!8#2P_C_E^9C!I'E
M`QFJY`,5JN`#%*H'``#0`P``T.?`!9%C8`*1`@"`DB$`@%+T]_^70?__%U;X
M_Y?Y:P6I5/C_E_U[O*FA``#0(4`WD?T#`)'S4P&ILP``\/43`/E@&D*Y(@!`
M^>(?`/D"`(#2./C_E_0#`*I@&D*Y-?C_E^(#`*J#XD(Y````L.'3`)$`P#N1
M0^0".9[Y_Y>```"T`0!`.3_$`''@"@!4:?S_EV`:0KDG^/^7`0``T&,`@%(A
M0`.1(@"`4CKX_Y?T`P"J@`$`M&`:0KD>^/^7@0I`^0(``-!"8`.1(0!`^?WW
M_Y>`"D#Y``!`^0`,0+G`"K`W8!I"N1/X_Y<!``#08P"`4B&``Y$B`(!2)OC_
ME_4#`*J@`0"TX=,`D0```+``@#J1>/G_E_0#`*I@&D*YM`<`M`3X_Y>A"D#Y
MX@,4JB$`0/GD]_^7M```\)3B")%@&D*Y_/?_E_4#`*I@&D*Y^??_ER(`@%(!
M``#0(:`#D3'X_Y<"``#0X0,`JD(`!)'@`Q6JU/?_EV`:0KGN]_^7X@,`JN'3
M`)$```"P`$`ZD5_D`CE8^?^7@`H`^?,#`*J@`@"T`3B`4N`#$ZIR^/^7`00`
M$3\$`'$$B%%ZP00`5*```-#A'T#Y`NA&^2$``NL"`(#2X0,`5/-30:GU$T#Y
M_7O$J,`#7]8`!$`Y0/7_-*C__Q>`!D#YQ_W_EX`*`/GS`P"J`/W_M0```-``
M(`21"?C_E[0``/"4X@B1QO?_EZ`*0/F!!D#Y``!`^2$`0/DV^O^7P___%V`:
M0KF^]_^7@0I`^2$`0/D7^/^7IO__%\GW_Y>!!D#YXP,`*N(#$ZH```#0`,`$
MD2$`0/GR]_^7'R`#U?U[O*FA``#0(4`WD?T#`)'S4P&I]`,`JO5;`JDB`$#Y
MXA\`^0(`@-*`!@"T`0!`.4$&`#37^?^7`0!`.?,#`*KA```T'R`#U0`$`)$_
MO`!Q<Q*`F@$`0#F!__\UM@``\)\"`/'U!Y\:P`)"N1\$`#'`!`!4'P``<>`'
MGQJU`@`*=0$`-:```-#A'T#Y`NA&^2$``NL"`(#2804`5/-30:GU6T*I_7O$
MJ,`#7]:``D`YH/[_-`$``+#@`Q.J(4`_D8(`@-)G]_^7X/W_-:```-#A'T#Y
M`NA&^2$``NL"`(#2(0,`5.`#%*KS4T&I]5M"J?U[Q*@?^?\7````L`!`-Y%X
M]_^7S?__%P```+#ATP"1`$`\D=OX_Y>@``"T``!`.1_``'$$&$!Z80``5-\"
M`KG5__\7(`"`4L`"`KE5^O\TV___%V_W_Y<?(`/5'R`#U?^#"M&A``#0XF,`
MD2%`-Y$%X`"1".`!D?U[`*GD`P*J_0,`D2,`0/GC3P'Y`P"`TJ$`0+F$0`"1
MHX1`^"$(P%J!`!_X8?Q@TV?\:-/G''B2)MQXTR$<"%/&''"2X^!#JB$`!JHA
M``.J@8`?^!\!!>L!_O]410`(D4$`0/E"(`"10P1`^40<0/EC``'*03!`^2$`
M!,HA``/*(_Q?TV$$`:HA?$"203P`^5\`!>MA_O]4!RA`J20SC](()$&I1%"K
M\N6;0:DC=)W2XOQ;T^S\0M-"%`>JC'D'JB$!",HCVZWR(0`*BB$`"<JE``2+
M(D`BBT']0M,A>`JJ0@`%BPL00/DM?$"2I0$(RL8`!(M"``L+I0`'BJ4`",HA
M``S*3OQ;TT_\0M.E``F+SA4"JJ4`!HLA``**XGD"JJ4`#@OFOT*I(0`-RJ[\
M6],A``B+SA4%JK#\0M/&``2+[P$$BR$`!HN&`0+*(0`."XQ]0)+&``6*Q@`,
MRB[\6]/&``V+SA4!J@UZ!:K&``^+Q@`."T4`#<KN'T#Y0GQ`DJ4``8HP_$+3
MI0`"RLX!!(NE``R+S_Q;TPQZ`:KO%0:JH0$,RJ4`#HON(T#YI0`/"ZU]0)(A
M``:*(0`-RL_\0M/F>0:J(0`"B\(!!(NN_%O3(0`"BZ_\0M."`0;*SA4%JBX`
M#@M"``6*Y7D%JHQ]0)+AOT2I0@`,RD(`#8O-_5O3K14.JM!\0)(A``2+0@`!
MB\$`!<I-``T+(0`.BB$`$,K&_4+3X@$$B\YX#JHA``R+K_U;TZ9\0)(A``*+
M[Q4-JJ(`#LJE_4+3+P`/"Z5X#:I"``V*X;=%J4(`!LI"`!"+[/U;TXP5#ZKP
M_4+3(0`$BT(``8O!`07*(0`/BLY]0)(A``[*3``,"P]Z#ZJB`02+(0`&BXW]
M6],A``*+H@`/RD(`#(JE?$"20@`%RJT5#*I"``Z++0`-"_"[1JF&_4+3QG@,
MJJ']6],L%`VJX0$&RB$`#8KO?4"2(0`/RA`"!(LA``6+0@`0B[#]0M-,``P+
M#7H-JL(!!(LA``*+P@`-RD(`#(K&?$"20@`&RH[]6]-"``^+SA4,JO"_1ZDN
M``X+A?U"TZ5X#*K!_5O3+!0.JJ$!!<HA``Z*K7U`DA`"!(LA``W*0@`0B]#]
M0M-,``P+#GH.JN(!!(LA``:+(0`"BZ(`#LI"``R*I7Q`DD(`!<J/_5O30@`-
MB^\5#*KPMTBI+P`/"X;]0M/&>`RJX?U;TRP4#ZK!`0;*(0`/BLY]0)(0`@2+
M(0`.RD(`$(OP_4+33``,"P]Z#ZJB`02+(0`%BR$``HO"``_*0@`,BL9\0))"
M``;*C?U;TT(`#HNM%0RJ\+M)J2T`#0N%_4+3I7@,JJ']6],L%`VJX0$%RB$`
M#8KO?4"2$`($BR$`#\I"`!"+L/U"TTP`#`L->@VJP@$$BR$`!HLA``*+H@`-
MRH[]6].E?$"20@`,BLX5#*I"``7*+@`."T(`#XN&_4+3X;]*J<QX#*K&_5O3
MQA0.JB$`!(OD`02+0@`!BZ$!#,HA``Z*K7U`DB$`#<K/_4+3T@`""^YY#JHA
M``6+0D`FB^]?0/DA``2+A`$.RD7^6].$``)*I102JN(!`XN$``V+3?Y"T[``
M`0NR>1*JA``"B^)C0/DA0"6+Q0$2R@;^6].E``%*QA00JD$``XL-_D+3HD`L
MB\\`!`NM>1"J0@`!B^%G0/F$0":+1@(-RN7]6]/$``1*I10/JB8``XN!0"Z+
ML0`""R$`!HOL_4+30D`EB^9K0/F/>0^JI0$/RB3^6].$%!&JI0`"2L(``XLF
M_D+3D``!"]%X$:KF;T#Y(4`DB^0!$<JL0#*+A``!2@7^6].E%!"J@@$"B\$`
M`XL,_D+3AD`MBZX``@N0>1"JP0`!B^9S0/E"0"6+)0(0RL3]6].B``)*A!0.
MJL8``XM"0"^+S/U"TXT``0N.>0ZJ0@`&B^9W0/DA0"2+!`(.RJ7]6].!``%*
MI10-JL8``XLA0#&+KP`""R$`!HNL_4+30D`EB^9[0/F->0VJQ0$-RN3]6].$
M%`^JI0`"2L(``XOF_4+3D0`!"\]X#ZKF?T#Y(4`DBZ0!#\JL0#"+A``!2B7^
M6].E%!&J@@$"B\$``XLL_D+3AD`NB[```@N,>1&JP0`!B^:#0/E"0"6+Y0$,
MR@3^6].B``)*A!00JL8``XM"0"V+#?Y"TXX``0M"``:+IGD0JO"'0/DA0"2+
MA`$&RL7]6].!``%*I10.JA`"`XLA0"^+K0`""R$`$(O/_4+30D`EB_"+0/GN
M>0ZJQ0`.RJ3]6].$%`VJI0`"2@("`XNP_4+3CP`!"PUZ#:KPCT#Y(4`DB\0!
M#<JL0"R+A``!2N7]6].E%`^JAD`FBP$"`XN"`0*+\/U"TZP``@O!``&+!GH/
MJO"30/E"0"6+I0$&RH3]6].B``)*A!0,JA`"`XM"0"Z+COU"TX\``0O,>0RJ
M0@`0B_"70/DA0"2+Q``,RN7]6].!``%*I10/JA`"`XLA0"V+[?U"TZX``@NO
M>0^J(0`0B_";0/E"0"6+A0$/RL3]6].B``)*A!0.JD)`)HL%`@.+T/U"TXT`
M`0M%``6+`GH.JO"?0/DA0"2+Y`$"RJ;]6].$``%*QA0-J@$"`XN$0"R+L/U"
MTX0``8L!>@VJS@`%"Z5`)HM&``'*Q0`%2LS]6].E0"^+S_U"TXP5#JKN>0ZJ
M\#]4J8T!!`N$0"R+IOU;T\84#:H0`@.+I0`0BS``#LK,``4+$`($2@)"(HOD
M`0.+L/U"TX_]6],->@VJ[Q4,JD(`!(NE0":+Y*M`^4(`#PO&`0W*Q0`%2H,`
M`XN&_4+3H4`ABT3\6]/,>`RJA!0"JB$``XLA``0+HP$,JN2O0/F%`0T*8P`"
MBD_\0M-C``6JAIN7TF;CL?+B>0*JA``&BV-`+HLE_%O3+OQ"TZ44`:IC``2+
MA`$"JF,`!0N$``&*P7D!JN4[5JE/``P*A``/JF_\0M.$0"V+;?Q;TZT5`ZJE
M``:+S@$&BX0`!8M%``&JA``-"Z4``XHM``(*I0`-JHW\6].E0"R+['D#JJ4`
M#HNC%02J+0`,JJ,``PONNT#YI0$$BHT!`0J/_$+3I0`-JLX!!HNE0"*+;?Q;
MT^)Y!*JM%0.JA`$"JJ4`#HONOT#YI0`-"X0``XI-``P*A``-JF_\0M/.`0:+
MA$`ABZW\6]/A>0.JK14%JH0`#HN$``T+0P`!JNW#0/DN``(*8P`%BJ_\0M-C
M``ZJY7D%JJT!!HMC0"R+COQ;TRP`!:K.%02J8P`-B^W'0/EC``X+C`$$BJX`
M`0J,`0ZJCOQ"TX)!(HNL`0:+;?Q;T\1Y!*JM%0.J0@`,BT(`#0NL``2J[<M`
M^8X`!0J,`0.*;_Q"TXP!#JKC>0.JK0$&BX%!(8M._%O3C``#JLX5`JHA``V+
M(0`."XP!`HIN``0*C`$.JD[\0M/">0*JA4$EB^V[6:DO_$+3K`$&BRW\6].M
M%0&JI0`,BVP``JJE``T+C`$!BDT``PJ,`0VJX7D!JLX!!HN$022+K?Q;TTP`
M`:JM%06JA``.B^[70/F$``T+C`$%BBT``@J,`0VJK_Q"T\X!!HN#02.+C?Q;
MT^QY!:JM%02J)0`,JF,`#HNE``2*[MM`^6,`#0N-`0$*C_Q"TZ4`#:KD>02J
MS@$&BZ)`(HMM_%O3A0$$JJT5`ZI"``Z+[M]`^4(`#0NE``.*C0`,"F_\0M.E
M``VJS@$&BZ%`(8M-_%O3Y7D#JJT5`JJ#``6J(0`.BT[\0M,A``T+8P`"BL)Y
M`JJO``0*[3M<J6,`#ZIL0"R+(_Q;TV,4`:HO_$+3K0$&BXP!#8NM``*J@P$#
M"ZP!`8I-``4*X7D!JHP!#:IM_%O3A$$DB\P!!HN$``R+3``!JBX``@J,`0.*
MC`$.JJT5`ZJ%026+A``-"^\S7:EM_$+3K7D#JH[\6]/.%02J[P$&BZ,`#XLE
M``VJ8P`."Z4`!(JN`0$*I0`.JH[\0M/$>02JHD`BBX4!!HML_%O3C!4#JD(`
M!8MN_$+3I0$$JD(`#`NE``.*PWD#JH\`#0KL.UZII0`/JJ5`(8M!_%O3(10"
MJD_\0M.,`0:+I0`,BXP``ZJE``$+C`$"BF$`!`KB>0*JC`$!JE```PJ!02V+
MS0$&BZS\6],A``V+C!4%JFT``JKN^T#YCP$!"ZT!!8HL0"R+K0$0JO#]0M.D
M022+S0$&BZ[\0M/F_5O3QA0/JH0`#8O->06JT0`$"^[_0/E!``W*(0`,2L4Z
MF-)%3+GR(4`CB\P!!8LC_EO3#WH/JF,4$:HA``R+A$`FB^X#0?EL``$+I@$/
MRB%`(XO$``1*Q@$%BX)`(HLN_D+3A/U;T]%Y$:J$%`RJ0@`&B^8'0?F0``(+
MXP$1RH[]0M-C``%*P0`%BV9`+8L#_EO3SGD,JL8``8MC%!"J0D`DB^$+0?EM
M``8+)`(.R@S^0M."``)*)``%BT)`+XNA_5O3D'D0JD0`!(LA%`VJPT`CB^(/
M0?DO``0+Q@$0RJS]0M/#``-*1@`%BV-`,8OB_5O3C7D-JF,`!HM"%`^J#`(-
MRN830?E1``,+@4`ABV)`(HN!`0%*Q``%BRQ`+HOF_4+3(?Y;T\]X#ZJ$`02+
M(101JN870?DN``0+HP$/RBS^0M-B``)*PP`%BT9`,(O"_5O3C'D1JL,``XM"
M%`ZJ@4`AB^8;0?E0``,+Y`$,RF)`(HN!``%*Q@`%BR1`+8O-_4+3`?Y;TZYY
M#JJ$``:+(100JN8?0?DM``0+@P$.RH%`(8MB``)*Q@`%BT-`+XL/_D+3HOU;
MT_!Y$*IC``:+0A0-JN8C0?E/``,+Q`$0RF)`(HN!``%*Q``%BRQ`+(NF_4+3
MX?U;T\UX#:J$`02+(10/JN8G0?DQ``0+`P(-RNS]0M-B``)*PP`%BT9`+HLB
M_EO3CWD/JL,``XM"%!&J@4`AB^8K0?E.``,+I`$/RBS^0M.!``%*Q@`%BR1`
M,(O!_5O3A``&BR$4#JJ&>1&J,``$"^PO0?EB0"*+XP$&RH%`(8MB``)*C`$%
MBT-`+8O-_4+3`OY;TZYY#JIC``R+0A00JNPS0?E-``,+Q``.RF)`(HN!``%*
MA`$%BRQ`+XL/_D+3H?U;TX0!!(LA%`VJ['D0JN\W0?DP``0+PP$,RH%`(8MC
M``)*X@$%BV9`)HNO_4+3`_Y;T^UY#:K&``*+8Q00JN([0?EO``8+A`$-RL-`
M(XN$``%*00`%BX1`+HOB_5O3#OY"TX0``8M"%`^JP7D0JNX_0?E0``0+I@$!
MRH)`(HO#``-*Q@$%BVQ`+(ON_4+3`_Y;TXP!!HO.>0^J8Q00JN9#0?EO``P+
M)``.RH-!(XN$``)*P@`%BX9`+8L-_D+3Y/U;TZUY$*K&``*+A!0/JN)'0?F0
M``8+S`$-RL9`)(N,`0-*0P`%BX%!(8L"_EO3(0`#BT(4$*HA``(+XOU"T^Q+
M0?E">`^JHP$"RB3\6]-F``9*A!0!JN=`+HN%`06+`_Y"TX0`!HMC>!"JI0`'
MBR$`"@MH``@+JP$+"T(`"0N$``4+!`0`J:,``+`("`&I"Q``^>!/0?EAZ$;Y
M```!ZP$`@-*!``!4_7M`J?^#"I'``U_63?/_E_U[OZD`$(#2_0,`D1'S_Y<?
M&`#Y)F"$TB5QE=+$GYO2PXZ*T@(^G-*FZ*SRI?F]\D07L_)#!J+R0GJX\@84
M`*D$#`&I`GP"J1]X`+G]>\&HP`-?UOU[O*E"?$"3_0,`D?-3`:D4X`"1\P,!
MJO5;`JGU`P"J]@,"JO=C`ZD%C$*I`'A`N:0,`@N_``3K8Y2#FF)T0HNDB@*I
M``0`-=_^`'$-!@!4U@(!4=A^!E,7!P`1]VIZTW<"%XM@!D"I@`8`J7,"`9%B
M#GVI@@X!J>`#%:IB#GZI@@X"J6(.?ZF"#@.IJ/O_EW\"%^N!_O]4UAH82^$#
M%ZK@`Q2JPGY`DYGR_Y>V>@"Y\U-!J?5;0JGW8T.I_7O$J,`#7]87"(!2]P(`
M2]\"%VN`PB"+U]*7&OA^0)/B`QBJB_+_EZ!Z0+G@`@`+H'H`N1\``7'A_?]4
MU@(72W,"&(O@`Q6JBOO_E]#__Q?W`Q.JX___%Q\@`]4?(`/5_7N\J?T#`)'S
M4P&I\P,!JO0#`*KU6P*I=>(`D>$/@!+W&P#Y8!9`^78J0+EW,D"Y`"`#4]8*
MP%H"!``1]PK`6J'*(#B@PB*+7^``<8T)`%0!"(!2(@`"2P$`@%)"?$"3N/+_
ME^`#$ZIJ^_^7?_X#J7_^!*E__@6I?S8`^7=:#BG@`Q.J8_O_EV$"0/G@`Q.J
M(?Q8TX$"`#EA`D#Y(?Q0TX$&`#EA`D#Y(?Q(TX$*`#EA`D#Y@0X`.6$&0/DA
M_%C3@1(`.6$&0/DA_%#3@18`.6$&0/DA_$C3@1H`.6$&0/F!'@`Y80I`^2'\
M6-.!(@`Y80I`^2'\4-.!)@`Y80I`^2'\2-.!*@`Y80I`^8$N`#EA#D#Y(?Q8
MTX$R`#EA#D#Y(?Q0TX$V`#EA#D#Y(?Q(TX$Z`#EA#D#Y@3X`.6$20/DA_%C3
M@4(`.6$20/DA_%#3@48`.6$20/DA_$C3@4H`.6$20/F!3@`Y\U-!J?5;0JGW
M&T#Y_7O$J-+R_Q<!!X!2(@`"2P$`@%)"?$"3;?+_E[O__Q<?(`/5'R`#U1\@
M`]7]>[RI_0,`D?-3`:FT``"PE"(WD?5;`JFU``"PM0(WD90"%<OV`P`J]V,#
MJ?<#`:KX`P*JE/Y#D_;Q_Y=T`0"T$P"`TA\@`]6C>G/XX@,8JG,&`)'A`Q>J
MX`,6*F``/]:?`A/K(?__5/-30:GU6T*I]V-#J?U[Q*C``U_6'R`#U<`#7]8?
M(`/5'R`#U1\@`]6C``#08_Q`^1KR_Q=?)`/5_7N_J?T#`)']>\&HP`-?U@$`
M`@```````````````````````````"]T;7``````+@````````!005)?5$U0
M1$E2````````5$U01$E2``!414U01$E2`%1%35``````5$U0``````!54T52
M`````%5315).04U%```````````E<R\E<P```"\`````````+W!R;V,O<V5L
M9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N
M86QS.CI005(Z.D)/3U0`````97AE```````O<')O8R\E:2\E<P``````4$%2
M7U1%35```````````%!!4E]04D]'3D%-10`````Z`````````"5S)7,E<P``
M4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)
M3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`
M````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/
M0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````4$%27T-,14%.
M/0```````#$`````````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>```
M``!P87(M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%!!
M5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M
M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````&`````````!P97)L
M`````#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-3$```!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``````````+64````````M+0```````&5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*
M;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N
M9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G
M;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T
M85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N
M(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM
M>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D
M8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M
M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D
M<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU
M;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(
M+"`D;6%G:6-?<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE
M("L@;&5N9W1H*"1005)?34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D
M8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL
M87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D
M;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR
M96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@
M=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM
M>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL
M92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@
M)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI
M.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\
M("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F
M(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I
M;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@
M>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@
M,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O
M?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U
M=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U
M;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^
M("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`
M24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["G!R:6YT("1F:"`D:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F
M:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M
M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T
M(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A
M<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@
M/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T
M82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD
M+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D
M92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\
M4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E
M9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?
M(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO
M861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I
M;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R
M97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D
M:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L
M("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C
M72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*
M?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D
M9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E
M9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S
M*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H
M<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E
M('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D
M9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*
M8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H
M*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M
M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@
M*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!
M0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C
M:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R
M:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T
M.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?
M9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T
M97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@
M)W(G*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A
M8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF
M;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF
M("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M
M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U[
M"EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM
M>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3
M<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*
M:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R
M97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE
M(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*
M?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O
M("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E
M<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O
M9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@
M6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A
M<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S
M<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@
M/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I
M(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L
M("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA
M;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H
M.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I
M97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E
M(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E
M<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,[
M"G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I
M9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES
M<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E
M<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X
M9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N
M)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D
M9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@
M(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@
M*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2
M(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E
M("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'
M3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N
M+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q
M(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T
M<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO
M9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN
M:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I
M;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@
M<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!
M4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T
M*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S
M8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<
M;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE
M>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE
M>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*
M`````'!E<FQX<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(```````````R$U```````#034``````````````````V$U`````
M``#H34```````/!-0```````^$U`````````3D``````````````````"$Y`
M```````03D```````````````````1L#.Q0!```A````N(S__P0&``#XCO__
M+`$``&B/__]``0``F(___U0!``#8C___:`$```B0__^,`0``&)#__Z`!```(
MD?__"`(``(B2__]@`@``*)/__X@"```LE/__O`(``%B5___T`@``;)?__T@#
M``#<E___;`,``!B8__^,`P``Z)C__[P#``#LF/__T`,```R;__\T!```.)O_
M_T@$``!8F___7`0``&R@__^4!```^*#__[@$```8H?__V`0``#BB__\4!0``
M3*G__YP%``"8J___R`4``.BL__\P!@``:+W__U0&``"\O?__=`8``-B^__^L
M!@``>,#__^`&``#XP/__%`<```C!__\H!P```````!```````````7I2``1X
M'@$;#!\`$````!@```#$C?__5`````!!!QX0````+````"".__\P````````
M`!````!`````/([__SP`````````(````%0```!HCO__,`````!!#B"=!)X#
M0I,"2-[=TPX`````$````'@```!TCO__!`````````!D````C````'".___L
M`````$$.0)T(G@="DP:4!4*8`9<"198#E015UM5!V-=#WMW3U`X`00Y`DP:4
M!94$E@.7`I@!G0B>!T_6U4'8UT'>W=/4#@!!#D"3!I0%G0B>!T*7`I@!0MC7
M`%0```#T````^([__WP!````00[0`9T:GAE(E!>3&$34TT?>W0X`00[0`9,8
ME!>=&IX91)<40Y85E19S"M330=;50==!"TG3U-76UT&4%Y,80985E19!EQ0D
M````3`$``""0__^8`````$$.L`&=%IX50Y,46`K>W=,.`$$+````,````'0!
M``"8D/__!`$```!!#B"=!)X#0I,"7PK>W=,.`$(+5`K>W=,.`$$+1M[=TPX`
M`#0```"H`0``:)'__R0!````0@[`($2=B`2>AP1"DX8$E(4$0Y6$!):#!&<*
MW=[5UM/4#@!!"P``4````.`!``!<DO__%`(```!!#F"=#)X+0I,*E`E-E0B6
M!Y<&F`5^"M[=U]C5UM/4#@!!"TB:`YD$7`K:V4$+2-G:0ID$F@-#V=I!F@.9
M!$+:V0``(````#0"```<E/__<`````!!#B"=!)X#0I,"4=[=TPX`````'```
M`%@"``!HE/__-`````!!#A"=`IX!1=[=#@`````L````>`(``(24___0````
M`$(.P$!#G8@(GH<(0I.&")2%"&L*W=[3U`X`00L````0````J`(``"25__\$
M`````````&````"\`@``%)7__R`"````0@[@(4.=G`2>FP1"DYH$E)D$0Y68
M!):7!%P*W=[5UM/4#@!!"T28E027E@1*F90$=0K8UT'900M5V-=!V4&7E@28
ME01!V-="F)4$EY8$09F4!``0````(`,``-"6__\D`````````!`````T`P``
MZ);__QP`````````-````$@#``#TEO__%`4```!!#H`!G1">#TB3#I0-E0R6
M"T*7"I@)`R`!"M[=U]C5UM/4#@!!"P`@````@`,``-";__^,`````$$.,)T&
MG@5$DP1/"M[=TPX`00L<````I`,``#B<__\@`````$$.$)T"G@%&WMT.````
M`#@```#$`P``.)S__Q@!````00Y`G0B>!T23!I0%0Y4$E@-7"M[=U=;3U`X`
M00M+"M[=U=;3U`X`00L``(0`````!```')W__Q0'````0@Z@@P)%G;(@GK$@
M1).P()2O()6N():M($.7K""8JR!:FJD@F:H@`F<*VME!W=[7V-76T]0.`$$+
M`IG9VD_=WM?8U=;3U`X`00Z@@P*3L""4KR"5KB"6K2"7K""8JR"9JB":J2"=
MLB">L2`"B=G:09JI()FJ(``H````B`0``*BC__](`@```$$.0)T(G@=$DP:4
M!4*5!`)H"M[=U=/4#@!!"S@```"T!```R*7__T@!````00Y`G0B>!T23!I0%
M0I4$E@-C"M[=U=;3U`X`00M2"M[=U=;3U`X`00L``"@```#P!```K(;__P0"
M````00Y0G0J>"423")0'`EL*WMW3U`X`00L`````(````!P%``"PIO__@!``
M``!!#J`%1YU4GE,#%@0*W=X.`$$+'````$`%```,M___5`````!!#A"=`IX!
M4][=#@`````T````8`4``$"W__\4`0```$$.0)T(G@=#DP:4!4.5!)8#0Y<"
MF`%F"M[=U]C5UM/4#@!!"P```#````"8!0``)+C__Y0!````00Y`G0B>!T*3
M!I0%0Y4$E@-#EP("50K>W=?5UM/4#@!!"P`P````S`4``)"Y__]\`````$$.
M0)T(G@="DP:4!4.5!)8#19<"F`%3WMW7V-76T]0.````$``````&``#<N?__
M!``````````0````%`8``-BY__\,````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````)`<0```````8!Q```````````````````$`
M````````"P,````````!`````````!L#`````````0`````````K`P``````
M``$`````````-0,````````,`````````!`50```````#0````````"<34``
M`````!D`````````P)U!```````;``````````@`````````&@````````#(
MG4$``````!P`````````"`````````#U_O]O`````)@"0```````!0``````
M``!("D````````8`````````0`-````````*`````````&X#````````"P``
M```````8`````````!4````````````````````#`````````.B?00``````
M`@````````#0!0```````!0`````````!P`````````7`````````$`/0```
M````!P````````"P#D````````@`````````D``````````)`````````!@`
M````````_O__;P````!0#D```````/___V\``````P````````#P__]O````
M`+8-0```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````V)U!````````````````````````````````````
M`````````````#`50```````,!5````````P%4```````#`50```````,!5`
M```````P%4```````#`50```````,!5````````P%4```````#`50```````
M,!5````````P%4```````#`50```````,!5````````P%4```````#`50```
M````,!5````````P%4```````#`50```````,!5````````P%4```````#`5
M0```````,!5````````P%4```````#`50```````,!5````````P%4``````
M`#`50```````,!5````````P%4```````#`50```````,!5````````P%4``
M`````#`50```````,!5````````P%4```````#`50```````,!5````````P
M%4```````#`50```````,!5````````P%4```````#`50```````,!5`````
M```P%4```````#`50```````,!5````````P%4```````#`50```````,!5`
M```````P%4```````#`50```````,!5````````P%4```````#`50```````
M,!5````````P%4```````#`50```````,!5````````P%4```````#`50```
M````,!5`````````````````````````````_____P````"(44```````$=#
M0SH@*$UA9V5I82`Q,"XR+C$M,"XR,#(P,3(P-2XQ+FUG83@I(#$P+C(N,2`R
M,#(P,3(P-0!'0T,Z("A-86=E:6$@,3`N,BXQ+3`N,C`R,#$R,3(N,2YM9V$X
M*2`Q,"XR+C$@,C`R,#$R,3(``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N
M<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?
M:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR
M96PN<F\`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M``````````````````````````````````L````!`````@`````````X`D``
M`````#@"````````&P````````````````````$````````````````````3
M````!P````(`````````5`)```````!4`@```````"0`````````````````
M```$````````````````````)@````<````"`````````'@"0```````>`(`
M```````@````````````````````!````````````````````#0```#V__]O
M`@````````"8`D```````)@"````````I``````````%``````````@`````
M```````````````^````"P````(`````````0`-```````!``P````````@'
M````````!@````$````(`````````!@`````````1@````,````"````````
M`$@*0```````2`H```````!N`P```````````````````0``````````````
M`````$X```#___]O`@````````"V#4```````+8-````````E@`````````%
M``````````(``````````@````````!;````_O__;P(`````````4`Y`````
M``!0#@```````&``````````!@````,````(````````````````````:@``
M``0````"`````````+`.0```````L`X```````"0``````````4`````````
M"``````````8`````````'0````$````0@````````!`#T```````$`/````
M````T`4````````%````%P````@`````````&`````````!^`````0````8`
M````````$!5````````0%0```````!@````````````````````$````````
M````````````>0````$````&`````````#`50```````,!4`````````!```
M````````````````$````````````````````(0````!````!@````````!`
M&4```````$`9````````7#0``````````````````$``````````````````
M``"*`````0````8`````````G$U```````"<30```````!0`````````````
M```````$````````````````````D`````$````"`````````+!-0```````
ML$T```````#8/@``````````````````"````````````````````)@````!
M`````@````````"(C$```````(B,````````%`$```````````````````0`
M``````````````````"F`````0````(`````````H(U```````"@C0``````
M`"@&```````````````````(````````````````````L`````X````#````
M`````,"=00``````P)T````````(````````````````````"``````````(
M`````````+P````/`````P````````#(G4$``````,B=````````"```````
M``````````````@`````````"`````````#(`````0````,`````````T)U!
M``````#0G0````````@````````````````````(````````````````````
MU0````8````#`````````-B=00``````V)T``````````@````````8`````
M````"``````````0`````````-X````!`````P````````#8GT$``````-B?
M````````$`````````````````````@`````````"`````````#C`````0``
M``,`````````Z)]!``````#HGP````````@"```````````````````(````
M``````@`````````[`````$````#`````````/"A00``````\*$````````@
M````````````````````"````````````````````/(````(`````P``````
M```0HD$``````!"B````````2!````````````````````@`````````````
M``````#W`````0```#`````````````````````0H@```````&X`````````
M```````````!``````````$``````````0````,`````````````````````
K````?J(``````````0```````````````````0``````````````````````
